==> brightcove-3.2.1.tar.gz: brightcove/src/Plugin/QueueWorker/BrightcoveSubscriptionsQueueWorker.php <==
<?php

declare(strict_types = 1);

namespace Drupal\brightcove\Plugin\QueueWorker;

use Brightcove\API\Exception\APIException;
use Brightcove\Item\Subscription;
use Drupal\brightcove\BrightcoveUtil;
use Drupal\brightcove\Services\LoggerInterface;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Gathers the subscriptions for creation and delete check.
 *
 * @QueueWorker(
 *   id = "brightcove_subscriptions_queue_worker",
 *   title = @Translation("Brightcove Subscriptions queue worker"),
 *   cron = {
 *     "time" = 30,
 *   },
 * )
 */
class BrightcoveSubscriptionsQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * Logger.
   *
   * @var \Drupal\brightcove\Services\LoggerInterface
   */
  protected $logger;

  /**
   * The brightcove_subscription create queue.
   *
   * @var \Drupal\Core\Queue\QueueInterface
   */
  protected $subscriptionQueue;

  /**
   * The brightcove_delete_subscription queue.
   *
   * @var \Drupal\Core\Queue\QueueInterface
   */
  protected $subscriptionDeleteQueue;

  /**
   * Constructs a new BrightcoveSubscriptionQueueWorker object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Queue\QueueInterface $subscription_queue
   *   The brightcove_subscription queue.
   * @param \Drupal\Core\Queue\QueueInterface $subscription_delete_queue
   *   The brightcove_delete_subscription queue.
   * @param \Drupal\brightcove\Services\LoggerInterface $logger
   *   Logger.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    QueueInterface $subscription_queue,
    QueueInterface $subscription_delete_queue,
    LoggerInterface $logger
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->subscriptionQueue = $subscription_queue;
    $this->subscriptionDeleteQueue = $subscription_delete_queue;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('queue')->get('brightcove_subscription_queue_worker'),
      $container->get('queue')->get('brightcove_subscription_delete_queue_worker'),
      $container->get('brightcove.logger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cms = BrightcoveUtil::getCmsApi($data);
    try {
      $subscriptions = $cms->getSubscriptions();

      foreach (!empty($subscriptions) ? $subscriptions : [] as $subscription) {
        if ($subscription instanceof Subscription) {
          $this->subscriptionQueue->createItem([
            'api_client_id' => $data,
            'subscription' => $subscription,
          ]);
        }
      }
    }
    catch (APIException $e) {
      if ($e->getCode() === 401) {
        $this->logger->logException($e, 'Access denied for Notifications.', [], RfcLogLevel::WARNING);
      }
      else {
        throw $e;
      }
    }
  }

}

==> brightcove-3.3.0.tar.gz: brightcove/src/Plugin/QueueWorker/BrightcoveSubscriptionsQueueWorker.php <==
<?php

declare(strict_types = 1);

namespace Drupal\brightcove\Plugin\QueueWorker;

use Brightcove\API\Exception\APIException;
use Brightcove\Item\Subscription;
use Drupal\brightcove\BrightcoveUtil;
use Drupal\brightcove\Services\LoggerInterface;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Gathers the subscriptions for creation and delete check.
 *
 * @QueueWorker(
 *   id = "brightcove_subscriptions_queue_worker",
 *   title = @Translation("Brightcove Subscriptions queue worker"),
 *   cron = {
 *     "time" = 30,
 *   },
 * )
 */
class BrightcoveSubscriptionsQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * Logger.
   *
   * @var \Drupal\brightcove\Services\LoggerInterface
   */
  protected $logger;

  /**
   * The brightcove_subscription create queue.
   *
   * @var \Drupal\Core\Queue\QueueInterface
   */
  protected $subscriptionQueue;

  /**
   * The brightcove_delete_subscription queue.
   *
   * @var \Drupal\Core\Queue\QueueInterface
   */
  protected $subscriptionDeleteQueue;

  /**
   * Constructs a new BrightcoveSubscriptionQueueWorker object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Queue\QueueInterface $subscription_queue
   *   The brightcove_subscription queue.
   * @param \Drupal\Core\Queue\QueueInterface $subscription_delete_queue
   *   The brightcove_delete_subscription queue.
   * @param \Drupal\brightcove\Services\LoggerInterface $logger
   *   Logger.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    QueueInterface $subscription_queue,
    QueueInterface $subscription_delete_queue,
    LoggerInterface $logger,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->subscriptionQueue = $subscription_queue;
    $this->subscriptionDeleteQueue = $subscription_delete_queue;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('queue')->get('brightcove_subscription_queue_worker'),
      $container->get('queue')->get('brightcove_subscription_delete_queue_worker'),
      $container->get('brightcove.logger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $cms = BrightcoveUtil::getCmsApi($data);
    try {
      $subscriptions = $cms->getSubscriptions();

      foreach (!empty($subscriptions) ? $subscriptions : [] as $subscription) {
        if ($subscription instanceof Subscription) {
          $this->subscriptionQueue->createItem([
            'api_client_id' => $data,
            'subscription' => $subscription,
          ]);
        }
      }
    }
    catch (APIException $e) {
      if ($e->getCode() === 401) {
        $this->logger->logException($e, 'Access denied for Notifications.', [], RfcLogLevel::WARNING);
      }
      else {
        throw $e;
      }
    }
  }

}
